==> jc-1.4.0.tar.gz: java/lang/ClassFormatError.h <==
// public class java.lang.ClassFormatError

// class file dependencies
// @dep_class c933004fd5a6148 java_lang_ClassFormatError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_ClassFormatError_H_
#define _JC_java_lang_ClassFormatError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ClassFormatError$sub_refs	_jc_java_lang_ClassFormatError$sub_refs;
typedef struct _jc_java_lang_ClassFormatError$sub_nonrefs	_jc_java_lang_ClassFormatError$sub_nonrefs;
typedef struct _jc_java_lang_ClassFormatError$refs	_jc_java_lang_ClassFormatError$refs;
typedef struct _jc_java_lang_ClassFormatError$nonrefs	_jc_java_lang_ClassFormatError$nonrefs;
typedef struct _jc_java_lang_ClassFormatError$object	_jc_java_lang_ClassFormatError$object;

typedef struct _jc_java_lang_ClassFormatError$fields_struct	_jc_java_lang_ClassFormatError$fields_struct;
typedef const struct _jc_java_lang_ClassFormatError$vmethods	_jc_java_lang_ClassFormatError$vmethods;
typedef const struct _jc_java_lang_ClassFormatError$vtable	_jc_java_lang_ClassFormatError$vtable;
typedef const struct _jc_java_lang_ClassFormatError$vtype	_jc_java_lang_ClassFormatError$vtype;

// Class fields structure
struct _jc_java_lang_ClassFormatError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ClassFormatError$fields_struct _jc_java_lang_ClassFormatError$class_fields;

// Constructors
extern void _jc_java_lang_ClassFormatError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ClassFormatError$object *);
extern void _jc_java_lang_ClassFormatError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ClassFormatError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_ClassFormatError$vmethods {
};

// Vtable
struct _jc_java_lang_ClassFormatError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_ClassFormatError$vmethods	java_lang_ClassFormatError;
};

// Vtype
struct _jc_java_lang_ClassFormatError$vtype {
	_jc_type			type;
	_jc_java_lang_ClassFormatError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ClassFormatError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ClassFormatError$refs {
    _jc_java_lang_ClassFormatError$sub_refs	java_lang_ClassFormatError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ClassFormatError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ClassFormatError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_ClassFormatError$sub_nonrefs	java_lang_ClassFormatError;
};

// Object instance structure
struct _jc_java_lang_ClassFormatError$object {
	_jc_java_lang_ClassFormatError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ClassFormatError$vtype	*vtype;
	_jc_java_lang_ClassFormatError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ClassFormatError$vtype _jc_java_lang_ClassFormatError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ClassFormatError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ClassFormatError$class_object;

#endif	/* _JC_java_lang_ClassFormatError_H_ */

==> jc-1.4.6.tar.gz: java/lang/ClassFormatError.h <==
// public class java.lang.ClassFormatError

// class file dependencies
// @dep_class c933004fd5a6148 java_lang_ClassFormatError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_ClassFormatError_H_
#define _JC_java_lang_ClassFormatError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ClassFormatError$sub_refs	_jc_java_lang_ClassFormatError$sub_refs;
typedef struct _jc_java_lang_ClassFormatError$sub_nonrefs	_jc_java_lang_ClassFormatError$sub_nonrefs;
typedef struct _jc_java_lang_ClassFormatError$refs	_jc_java_lang_ClassFormatError$refs;
typedef struct _jc_java_lang_ClassFormatError$nonrefs	_jc_java_lang_ClassFormatError$nonrefs;
typedef struct _jc_java_lang_ClassFormatError$object	_jc_java_lang_ClassFormatError$object;

typedef struct _jc_java_lang_ClassFormatError$fields_struct	_jc_java_lang_ClassFormatError$fields_struct;
typedef const struct _jc_java_lang_ClassFormatError$vmethods	_jc_java_lang_ClassFormatError$vmethods;
typedef const struct _jc_java_lang_ClassFormatError$vtable	_jc_java_lang_ClassFormatError$vtable;
typedef const struct _jc_java_lang_ClassFormatError$vtype	_jc_java_lang_ClassFormatError$vtype;

// Class fields structure
struct _jc_java_lang_ClassFormatError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ClassFormatError$fields_struct _jc_java_lang_ClassFormatError$class_fields;

// Constructors
extern void _jc_java_lang_ClassFormatError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ClassFormatError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ClassFormatError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ClassFormatError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ClassFormatError$vmethods {
};

// Vtable
struct _jc_java_lang_ClassFormatError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_ClassFormatError$vmethods	java_lang_ClassFormatError;
};

// Vtype
struct _jc_java_lang_ClassFormatError$vtype {
	_jc_type			type;
	_jc_java_lang_ClassFormatError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ClassFormatError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ClassFormatError$refs {
    _jc_java_lang_ClassFormatError$sub_refs	java_lang_ClassFormatError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ClassFormatError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ClassFormatError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_ClassFormatError$sub_nonrefs	java_lang_ClassFormatError;
};

// Object instance structure
struct _jc_java_lang_ClassFormatError$object {
	_jc_java_lang_ClassFormatError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ClassFormatError$vtype	*vtype;
	_jc_java_lang_ClassFormatError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ClassFormatError$vtype _jc_java_lang_ClassFormatError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ClassFormatError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ClassFormatError$class_object;

#endif	/* _JC_java_lang_ClassFormatError_H_ */
